aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/layoutmgr/LayoutManager.java
diff options
context:
space:
mode:
authorGlen Mazza <gmazza@apache.org>2004-05-18 11:42:08 +0000
committerGlen Mazza <gmazza@apache.org>2004-05-18 11:42:08 +0000
commit922918acfefd17dd6487f1f0b2bb43a016ae2be5 (patch)
treef85eb1d454d683a586b8946fba0d03e167e24eed /src/java/org/apache/fop/layoutmgr/LayoutManager.java
parente1d05fb542d88054deff0fe0ff01dd01fc401294 (diff)
downloadxmlgraphics-fop-922918acfefd17dd6487f1f0b2bb43a016ae2be5.tar.gz
xmlgraphics-fop-922918acfefd17dd6487f1f0b2bb43a016ae2be5.zip
Folded the layout strategy into apps.Document.
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@197605 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org/apache/fop/layoutmgr/LayoutManager.java')
-rw-r--r--src/java/org/apache/fop/layoutmgr/LayoutManager.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/java/org/apache/fop/layoutmgr/LayoutManager.java b/src/java/org/apache/fop/layoutmgr/LayoutManager.java
index c4662164d..54ade889a 100644
--- a/src/java/org/apache/fop/layoutmgr/LayoutManager.java
+++ b/src/java/org/apache/fop/layoutmgr/LayoutManager.java
@@ -71,10 +71,10 @@ public interface LayoutManager {
LayoutManager getParent();
/**
* Get the LayoutManagerLS object that is at the top of the LM Tree
* @return the LayoutManagerLS object that is at the top of the LM Tree
*/
- LayoutManagerLS getLayoutManagerLS();
+ org.apache.fop.apps.Document getDocument();
/**
* Initialize this layout manager.
@@ -71,10 +71,10 @@ public interface LayoutManager {
LayoutManager getParent();
/**
- * Get the LayoutManagerLS object that is at the top of the LM Tree
- * @return the LayoutManagerLS object that is at the top of the LM Tree
+ * Get the Document object that is at the top of the LM Tree
+ * @return the Document object that is at the top of the LM Tree
*/